@@ -125,23 +125,32 @@ The MRI compiler uses this, which is a repeat of type 5:
 #include "libiberty.h"
 #include "safe-ctype.h"
 
-static void ihex_init PARAMS ((void));
-static boolean ihex_mkobject PARAMS ((bfd *));
-static INLINE int ihex_get_byte PARAMS ((bfd *, boolean *));
-static void ihex_bad_byte PARAMS ((bfd *, unsigned int, int, boolean));
-static boolean ihex_scan PARAMS ((bfd *));
-static const bfd_target *ihex_object_p PARAMS ((bfd *));
-static boolean ihex_read_section PARAMS ((bfd *, asection *, bfd_byte *));
-static boolean ihex_get_section_contents
+static void ihex_init
+  PARAMS ((void));
+static bfd_boolean ihex_mkobject
+  PARAMS ((bfd *));
+static INLINE int ihex_get_byte
+  PARAMS ((bfd *, bfd_boolean *));
+static void ihex_bad_byte
+  PARAMS ((bfd *, unsigned int, int, bfd_boolean));
+static bfd_boolean ihex_scan
+  PARAMS ((bfd *));
+static const bfd_target *ihex_object_p
+  PARAMS ((bfd *));
+static bfd_boolean ihex_read_section
+  PARAMS ((bfd *, asection *, bfd_byte *));
+static bfd_boolean ihex_get_section_contents
   PARAMS ((bfd *, asection *, PTR, file_ptr, bfd_size_type));
-static boolean ihex_set_section_contents
+static bfd_boolean ihex_set_section_contents
   PARAMS ((bfd *, asection *, PTR, file_ptr, bfd_size_type));
-static boolean ihex_write_record
+static bfd_boolean ihex_write_record
   PARAMS ((bfd *, size_t, unsigned int, unsigned int, bfd_byte *));
-static boolean ihex_write_object_contents PARAMS ((bfd *));
-static boolean ihex_set_arch_mach
+static bfd_boolean ihex_write_object_contents
+  PARAMS ((bfd *));
+static bfd_boolean ihex_set_arch_mach
   PARAMS ((bfd *, enum bfd_architecture, unsigned long));
-static int ihex_sizeof_headers PARAMS ((bfd *, boolean));
+static int ihex_sizeof_headers
+  PARAMS ((bfd *, bfd_boolean));
 
 /* The number of bytes we put on one line during output.  */
 
@@ -178,18 +187,18 @@ struct ihex_data_struct
 static void
 ihex_init ()
 {
-  static boolean inited;
+  static bfd_boolean inited;
 
   if (! inited)
     {
-      inited = true;
+      inited = TRUE;
       hex_init ();
     }
 }
 
 /* Create an ihex object.  */
 
-static boolean
+static bfd_boolean
 ihex_mkobject (abfd)
      bfd *abfd;
 {
@@ -198,12 +207,12 @@ ihex_mkobject (abfd)
 
   tdata = (struct ihex_data_struct *) bfd_alloc (abfd, amt);
   if (tdata == NULL)
-    return false;
+    return FALSE;
 
   abfd->tdata.ihex_data = tdata;
   tdata->head = NULL;
   tdata->tail = NULL;
-  return true;
+  return TRUE;
 }
 
 /* Read a byte from a BFD.  Set *ERRORPTR if an error occurred.
@@ -212,14 +221,14 @@ ihex_mkobject (abfd)
 static INLINE int
 ihex_get_byte (abfd, errorptr)
      bfd *abfd;
-     boolean *errorptr;
+     bfd_boolean *errorptr;
 {
   bfd_byte c;
 
   if (bfd_bread (&c, (bfd_size_type) 1, abfd) != 1)
     {
       if (bfd_get_error () != bfd_error_file_truncated)
-	*errorptr = true;
+	*errorptr = TRUE;
       return EOF;
     }
 
@@ -233,7 +242,7 @@ ihex_bad_byte (abfd, lineno, c, error)
      bfd *abfd;
      unsigned int lineno;
      int c;
-     boolean error;
+     bfd_boolean error;
 {
   if (c == EOF)
     {
@@ -261,7 +270,7 @@ ihex_bad_byte (abfd, lineno, c, error)
 /* Read an Intel hex file and turn it into sections.  We create a new
    section for each contiguous set of bytes.  */
 
-static boolean
+static bfd_boolean
 ihex_scan (abfd)
      bfd *abfd;
 {
@@ -269,7 +278,7 @@ ihex_scan (abfd)
   bfd_vma extbase;
   asection *sec;
   unsigned int lineno;
-  boolean error;
+  bfd_boolean error;
   bfd_byte *buf = NULL;
   size_t bufsize;
   int c;
@@ -283,7 +292,7 @@ ihex_scan (abfd)
   extbase = 0;
   sec = NULL;
   lineno = 1;
-  error = false;
+  error = FALSE;
   bufsize = 0;
 
   while ((c = ihex_get_byte (abfd, &error)) != EOF)
@@ -407,7 +416,7 @@ ihex_scan (abfd)
 		abfd->start_address = addr;
 	      if (buf != NULL)
 		free (buf);
-	      return true;
+	      return TRUE;
 
 	    case 2:
 	      /* An extended address record.  */
@@ -496,12 +505,12 @@ ihex_scan (abfd)
   if (buf != NULL)
     free (buf);
 
-  return true;
+  return TRUE;
 
  error_return:
   if (buf != NULL)
     free (buf);
-  return false;
+  return FALSE;
 }
 
 /* Try to recognize an Intel Hex file.  */
@@ -563,7 +572,7 @@ ihex_object_p (abfd)
 
 /* Read the contents of a section in an Intel Hex file.  */
 
-static boolean
+static bfd_boolean
 ihex_read_section (abfd, section, contents)
      bfd *abfd;
      asection *section;
@@ -573,14 +582,14 @@ ihex_read_section (abfd, section, contents)
   bfd_byte *p;
   bfd_byte *buf = NULL;
   size_t bufsize;
-  boolean error;
+  bfd_boolean error;
 
   if (bfd_seek (abfd, section->filepos, SEEK_SET) != 0)
     goto error_return;
 
   p = contents;
   bufsize = 0;
-  error = false;
+  error = FALSE;
   while ((c = ihex_get_byte (abfd, &error)) != EOF)
     {
       char hdr[8];
@@ -631,7 +640,7 @@ ihex_read_section (abfd, section, contents)
 	  /* We've read everything in the section.  */
 	  if (buf != NULL)
 	    free (buf);
-	  return true;
+	  return TRUE;
 	}
 
       /* Skip the checksum.  */
@@ -651,17 +660,17 @@ ihex_read_section (abfd, section, contents)
   if (buf != NULL)
     free (buf);
 
-  return true;
+  return TRUE;
 
  error_return:
   if (buf != NULL)
     free (buf);
-  return false;
+  return FALSE;
 }
 
 /* Get the contents of a section in an Intel Hex file.  */
 
-static boolean
+static bfd_boolean
 ihex_get_section_contents (abfd, section, location, offset, count)
      bfd *abfd;
      asection *section;
@@ -673,20 +682,20 @@ ihex_get_section_contents (abfd, section, location, offset, count)
     {
       section->used_by_bfd = bfd_alloc (abfd, section->_raw_size);
       if (section->used_by_bfd == NULL)
-	return false;
+	return FALSE;
       if (! ihex_read_section (abfd, section, section->used_by_bfd))
-	return false;
+	return FALSE;
     }
 
   memcpy (location, (bfd_byte *) section->used_by_bfd + offset,
 	  (size_t) count);
 
-  return true;
+  return TRUE;
 }
 
 /* Set the contents of a section in an Intel Hex file.  */
 
-static boolean
+static bfd_boolean
 ihex_set_section_contents (abfd, section, location, offset, count)
      bfd *abfd;
      asection *section;
@@ -702,16 +711,16 @@ ihex_set_section_contents (abfd, section, location, offset, count)
   if (count == 0
       || (section->flags & SEC_ALLOC) == 0
       || (section->flags & SEC_LOAD) == 0)
-    return true;
+    return TRUE;
 
   amt = sizeof (struct ihex_data_list);
   n = (struct ihex_data_list *) bfd_alloc (abfd, amt);
   if (n == NULL)
-    return false;
+    return FALSE;
 
   data = (bfd_byte *) bfd_alloc (abfd, count);
   if (data == NULL)
-    return false;
+    return FALSE;
   memcpy (data, location, (size_t) count);
 
   n->data = data;
@@ -742,12 +751,12 @@ ihex_set_section_contents (abfd, section, location, offset, count)
 	tdata->tail = n;
     }
 
-  return true;
+  return TRUE;
 }
 
 /* Write a record out to an Intel Hex file.  */
 
-static boolean
+static bfd_boolean
 ihex_write_record (abfd, count, addr, type, data)
      bfd *abfd;
      size_t count;
@@ -785,14 +794,14 @@ ihex_write_record (abfd, count, addr, type, data)
 
   total = 9 + count * 2 + 4;
   if (bfd_bwrite (buf, (bfd_size_type) total, abfd) != total)
-    return false;
+    return FALSE;
 
-  return true;
+  return TRUE;
 }
 
 /* Write out an Intel Hex file.  */
 
-static boolean
+static bfd_boolean
 ihex_write_object_contents (abfd)
      bfd *abfd;
 {
@@ -834,7 +843,7 @@ ihex_write_object_contents (abfd)
 		  addr[0] = (bfd_byte)(segbase >> 12) & 0xff;
 		  addr[1] = (bfd_byte)(segbase >> 4) & 0xff;
 		  if (! ihex_write_record (abfd, 2, 0, 2, addr))
-		    return false;
+		    return FALSE;
 		}
 	      else
 		{
@@ -849,7 +858,7 @@ ihex_write_object_contents (abfd)
 		      addr[0] = 0;
 		      addr[1] = 0;
 		      if (! ihex_write_record (abfd, 2, 0, 2, addr))
-			return false;
+			return FALSE;
 		      segbase = 0;
 		    }
 
@@ -863,12 +872,12 @@ ihex_write_object_contents (abfd)
 			(_("%s: address 0x%s out of range for Intel Hex file"),
 			 bfd_get_filename (abfd), buf);
 		      bfd_set_error (bfd_error_bad_value);
-		      return false;
+		      return FALSE;
 		    }
 		  addr[0] = (bfd_byte)(extbase >> 24) & 0xff;
 		  addr[1] = (bfd_byte)(extbase >> 16) & 0xff;
 		  if (! ihex_write_record (abfd, 2, 0, 4, addr))
-		    return false;
+		    return FALSE;
 		}
 	    }
 
@@ -879,7 +888,7 @@ ihex_write_object_contents (abfd)
             now = 0x10000 - rec_addr;
 
 	  if (! ihex_write_record (abfd, now, rec_addr, 0, p))
-	    return false;
+	    return FALSE;
 
 	  where += now;
 	  p += now;
@@ -901,7 +910,7 @@ ihex_write_object_contents (abfd)
 	  startbuf[2] = (bfd_byte)(start >> 8) & 0xff;
 	  startbuf[3] = (bfd_byte)start & 0xff;
 	  if (! ihex_write_record (abfd, 4, 0, 3, startbuf))
-	    return false;
+	    return FALSE;
 	}
       else
 	{
@@ -910,20 +919,20 @@ ihex_write_object_contents (abfd)
 	  startbuf[2] = (bfd_byte)(start >> 8) & 0xff;
 	  startbuf[3] = (bfd_byte)start & 0xff;
 	  if (! ihex_write_record (abfd, 4, 0, 5, startbuf))
-	    return false;
+	    return FALSE;
 	}
     }
 
   if (! ihex_write_record (abfd, 0, 0, 1, NULL))
-    return false;
+    return FALSE;
 
-  return true;
+  return TRUE;
 }
 
 /* Set the architecture for the output file.  The architecture is
    irrelevant, so we ignore errors about unknown architectures.  */
 
-static boolean
+static bfd_boolean
 ihex_set_arch_mach (abfd, arch, mach)
      bfd *abfd;
      enum bfd_architecture arch;
@@ -932,9 +941,9 @@ ihex_set_arch_mach (abfd, arch, mach)
   if (! bfd_default_set_arch_mach (abfd, arch, mach))
     {
       if (arch != bfd_arch_unknown)
-	return false;
+	return FALSE;
     }
-  return true;
+  return TRUE;
 }
 
 /* Get the size of the headers, for the linker.  */
@@ -943,7 +952,7 @@ ihex_set_arch_mach (abfd, arch, mach)
 static int
 ihex_sizeof_headers (abfd, exec)
      bfd *abfd ATTRIBUTE_UNUSED;
-     boolean exec ATTRIBUTE_UNUSED;
+     bfd_boolean exec ATTRIBUTE_UNUSED;
 {
   return 0;
 }
