@@ -1,6 +1,6 @@
 /* tc-i386.h -- Header file for tc-i386.c
    Copyright 1989, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000,
-   2001, 2002
+   2001, 2002, 2003
    Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
@@ -471,20 +471,15 @@ extern int tc_i386_fix_adjustable PARAMS ((struct fix *));
 #define MD_APPLY_SYM_VALUE(FIX) 0
 
 /* ELF wants external syms kept, as does PE COFF.  */
-#ifdef TE_PE
-# ifdef STRICT_PE_FORMAT
-#   define EXTERN_FORCE_RELOC				\
+#if defined (TE_PE) && defined (STRICT_PE_FORMAT)
+#define EXTERN_FORCE_RELOC				\
   (OUTPUT_FLAVOR == bfd_target_elf_flavour		\
    || OUTPUT_FLAVOR == bfd_target_coff_flavour)
-# endif
 #else
 #define EXTERN_FORCE_RELOC				\
   (OUTPUT_FLAVOR == bfd_target_elf_flavour)
 #endif
 
-#define TC_FORCE_RELOCATION(FIX)	i386_force_relocation (FIX)
-extern boolean i386_force_relocation PARAMS ((struct fix *));
-
 /* This expression evaluates to true if the relocation is for a local
    object for which we still want to do the relocation at runtime.
    False if we are willing to perform this relocation while building
@@ -513,7 +508,7 @@ extern boolean i386_force_relocation PARAMS ((struct fix *));
 
 /* For COFF.  */
 #define TC_FORCE_RELOCATION(FIX)			\
-  ((FIX)->fx_r_type == 7 || S_FORCE_RELOC ((FIX)->fx_addsy))
+  ((FIX)->fx_r_type == 7 || generic_force_reloc (FIX))
 #endif /* ! BFD_ASSEMBLER */
 
 #define md_operand(x)
@@ -550,4 +545,19 @@ void i386_print_statistics PARAMS ((FILE *));
 extern void sco_id PARAMS ((void));
 #endif
 
+/* We want .cfi_* pseudo-ops for generating unwind info.  */
+#define TARGET_USE_CFIPOP
+#ifdef TARGET_USE_CFIPOP
+
+#define tc_cfi_init() tc_x86_cfi_init ()
+extern void tc_x86_cfi_init PARAMS ((void));
+
+#define tc_regname_to_dw2regnum tc_x86_regname_to_dw2regnum
+extern unsigned long tc_x86_regname_to_dw2regnum PARAMS ((const char *regname));
+
+#define tc_cfi_frame_initial_instructions tc_x86_frame_initial_instructions
+extern void tc_x86_frame_initial_instructions PARAMS ((void));
+
+#endif /* TARGET_USE_CFIPOP */
+
 #endif /* TC_I386 */
